Keywords: Supreme Court of the United States, Supreme Court, Supreme Court of US, Supremecourt, United State Supreme Court, US Supreme Court, U.S. Supreme Court, Court, Argument, Arguments, Audio, Arguments Audio

Visiting the Court | Touring the Building | Exhibitions

Search: All Documents Docket
Enter Search Text:

Home | Oral Arguments | Argument Audio - October Term 2014

### Argument Audio

The audio recordings of all oral arguments heard by the Supreme Court of the United States are available to the public at the end of each argument week. The audio recordings are posted on Fridays after Conference.

The public may either download the audio files or listen to the recordings on the Court’s Web site. The audio recordings are listed by case name, docket number, and the date of oral argument.

The Court began audio recording oral arguments in 1955. The recordings are maintained at The National Archives and Records Administration. Prior to the 2010 Term, the recordings from one Term of Court were not available until the beginning of the next Term. The Archives will continue to serve as the official repository for the Court’s audio recordings.

2014 2013 2012 2011 2010

### Term Year: 2014

Argument Session: October 06, 2014 - October 15, 2014 | Date Argued
13-604. Heien v. North Carolina | 10/06/14
13-6827. Holt v. Hobbs | 10/07/14
13-719. Dart Cherokee Basin Operating Co. v. Owens | 10/07/14
13-433. Integrity Staffing Solutions, Inc. v. Busk | 10/08/14
13-517. Warger v. Shauers | 10/08/14
126-Orig. Kansas v. Nebraska | 10/14/14
13-534. North Carolina State Bd. of Dental Examiners v. FTC | 10/14/14
13-854. Teva Pharmaceuticals USA, Inc. v. Sandoz, Inc. | 10/15/14
13-7211. Jennings v. Stevens | 10/15/14

November 04, 2014 | Version 2014.1
Home | Help | Site Map | Contact Us | About Us | FAQ | Jobs | Links | Building Regulations
Website Policies and Notices | Privacy Policy | USA.GOV
Supreme Court of the United States